aboutsummaryrefslogtreecommitdiffstats
path: root/lib/erl_docgen/src
diff options
context:
space:
mode:
authorLars Thorsen <[email protected]>2011-11-16 15:14:07 +0100
committerLars Thorsen <[email protected]>2011-11-18 14:28:44 +0100
commite2b2f74fabb79a5fa7638ca65dcc2d4e8ab332c2 (patch)
tree257556955c3e41ac744dc7237194060c9c7fb025 /lib/erl_docgen/src
parent2da3a1fb06caf0c7fc53a8efdfbc769278b4323f (diff)
downloadotp-e2b2f74fabb79a5fa7638ca65dcc2d4e8ab332c2.tar.gz
otp-e2b2f74fabb79a5fa7638ca65dcc2d4e8ab332c2.tar.bz2
otp-e2b2f74fabb79a5fa7638ca65dcc2d4e8ab332c2.zip
[erl_docgen] Update references to modules that changed name
Diffstat (limited to 'lib/erl_docgen/src')
-rw-r--r--lib/erl_docgen/src/Makefile4
-rw-r--r--lib/erl_docgen/src/docgen_edoc_xml_cb.erl30
-rw-r--r--lib/erl_docgen/src/docgen_otp_specs.erl2
-rw-r--r--lib/erl_docgen/src/docgen_xmerl_xml_cb.erl10
-rw-r--r--lib/erl_docgen/src/erl_docgen.app.src4
5 files changed, 24 insertions, 26 deletions
diff --git a/lib/erl_docgen/src/Makefile b/lib/erl_docgen/src/Makefile
index 8e81bccd59..8c56784342 100644
--- a/lib/erl_docgen/src/Makefile
+++ b/lib/erl_docgen/src/Makefile
@@ -35,7 +35,9 @@ RELSYSDIR = $(RELEASE_PATH)/lib/erl_docgen-$(VSN)
# Target Specs
# ----------------------------------------------------
MODULES = \
- otp_specs
+ docgen_otp_specs \
+ docgen_edoc_xml_cb \
+ docgen_xmerl_xml_cb
HRL_FILES =
diff --git a/lib/erl_docgen/src/docgen_edoc_xml_cb.erl b/lib/erl_docgen/src/docgen_edoc_xml_cb.erl
index 90491bc007..dc9bc565ee 100644
--- a/lib/erl_docgen/src/docgen_edoc_xml_cb.erl
+++ b/lib/erl_docgen/src/docgen_edoc_xml_cb.erl
@@ -15,17 +15,13 @@
%%
%% $Id$
%%
--module(docb_edoc_xml_cb).
+-module(docgen_edoc_xml_cb).
-%% This is the EDoc callback module for creating DocBuilder erlref
-%% documents (man pages) in XML format, and also a DocBuilder chapter
+%% This is the EDoc callback module for creating erlref
+%% documents (man pages) in XML format, and also a chapter
%% document based on "overview.edoc".
%%
-%% Usage examples:
-%% docb_gen File
-%% docb_gen -chapter overview.edoc
-%% or (from an Erlang shell)
-%% edoc:file(File, [{layout,docb_edoc_xml_cb},{file_suffix,".xml"},
+%% edoc:file(File, [{layout,docgen_edoc_xml_cb},{file_suffix,".xml"},
%% {preprocess,true}]).
%%
%% The origin of this file is the edoc module otpsgml_layout.erl
@@ -43,12 +39,12 @@
module(Element, Opts) ->
SortP = proplists:get_value(sort_functions, Opts, true),
XML = layout_module(Element, SortP),
- xmerl:export_simple([XML], docb_xmerl_xml_cb, []).
+ xmerl:export_simple([XML], docgen_xmerl_xml_cb, []).
%% CHAPTER
overview(Element, _Opts) ->
XML = layout_chapter(Element),
- xmerl:export_simple([XML], docb_xmerl_xml_cb, []).
+ xmerl:export_simple([XML], docgen_xmerl_xml_cb, []).
%%--Internal functions--------------------------------------------------
@@ -433,12 +429,11 @@ otp_xmlify_e(E) ->
%% Takes an <a> element and filters the attributes to decide wheather
%% its a seealso/url or a marker.
%% In the case of a seealso/url, the href part is checked, making
-%% sure a .xml/.html file extension is removed (as DocBuilder inserts
-%% .html extension when resolving cross references).
+%% sure a .xml/.html file extension is removed.
%% Also, references to other applications //App has a href attribute
-%% value "OTPROOT/..." (due to app_default being set to "OTPROOT" in
-%% docb_gen.erl), in this case both href attribute and content must be
-%% formatted correctly according to DocBuilder requirements.
+%% value "OTPROOT/..." (due to app_default being set to "OTPROOT")
+%% , in this case both href attribute and content must be
+%% formatted correctly according to requirements.
otp_xmlify_a(A) ->
[Attr0] = filter_a_attrs(A#xmlElement.attributes),
case Attr0 of
@@ -521,9 +516,8 @@ otp_xmlify_a_fileref(FileRef1, AppS) ->
File;
[File, Ext, Marker0] ->
%% Here is an awkward solution to an awkward problem
- %% The marker automatically inserted by DocBuilder at
- %% each function does not seem to work for EDoc generated
- %% ERLREFs.
+ %% The marker automatically inserted at each function
+ %% does not seem to work for EDoc generated ERLREFs.
%% So if the referenced marker is in an ERLREF generated
%% by EDoc, keep it "as is", ie "function-arity".
%% If the referenced marker is NOT in an ERLREF generated
diff --git a/lib/erl_docgen/src/docgen_otp_specs.erl b/lib/erl_docgen/src/docgen_otp_specs.erl
index edb437a942..3929e66515 100644
--- a/lib/erl_docgen/src/docgen_otp_specs.erl
+++ b/lib/erl_docgen/src/docgen_otp_specs.erl
@@ -17,7 +17,7 @@
%% %CopyrightEnd%
%%
--module(otp_specs).
+-module(docgen_otp_specs).
-export([module/2, package/2, overview/2, type/1]).
diff --git a/lib/erl_docgen/src/erl_docgen.app.src b/lib/erl_docgen/src/erl_docgen.app.src
index 1720464b6d..daad172106 100644
--- a/lib/erl_docgen/src/erl_docgen.app.src
+++ b/lib/erl_docgen/src/erl_docgen.app.src
@@ -1,7 +1,9 @@
{application, erl_docgen,
[{description, "Misc tools for building documentation"},
{vsn, "%VSN%"},
- {modules, [otp_specs
+ {modules, [docgen_otp_specs,
+ docgen_edoc_xml_cb,
+ docgen_xmerl_xml_cb
]
},
{registered,[]},
diff --git a/lib/erl_docgen/src/docgen_xmerl_xml_cb.erl b/lib/erl_docgen/src/docgen_xmerl_xml_cb.erl
index 089b8f0c7d..884932ed12 100644
--- a/lib/erl_docgen/src/docgen_xmerl_xml_cb.erl
+++ b/lib/erl_docgen/src/docgen_xmerl_xml_cb.erl
@@ -15,11 +15,11 @@
%%
%% $Id$
%%
--module(docb_xmerl_xml_cb).
+-module(docgen_xmerl_xml_cb).
-%% This is the callback module for exporting XHTML to a DocBuilder
+%% This is the callback module for exporting XHTML to an
%% erlref or chapter document in XML format.
%% See docb_edoc_xml_cb.erl for further information.
%%
%% The origin of this file is the xmerl module xmerl_otpsgml.erl
%% written by Ulf Wiger and Richard Carlsson.
@@ -83,6 +83,6 @@ is_url("http:"++_) -> true;
is_url("../"++_) -> true;
is_url(FileRef) ->
case filename:extension(FileRef) of
- "" -> false; % no extension = xml file, DocBuilder resolves
- _Ext -> true % extension, DocBuilder must not resolve
+ "" -> false; % no extension = xml file
+ _Ext -> true % extension
end.
@@ -15,11 +15,11 @@
%% erlref or chapter document in XML format.
-%% See docb_edoc_xml_cb.erl for further information.
+%% See docgen_edoc_xml_cb.erl for further information.
%%
%% The origin of this file is the xmerl module xmerl_otpsgml.erl